@@ -5,6 +5,7 @@
  * @file
  *
  * @author JJohnson
+ * @author Omnipaedista
  * @author Spacebirdy
  * @author Wōdenhelm
  */
@@ -121,6 +122,7 @@ $messages = array(
 'permalink'         => 'Fæst bend',
 'print'             => 'Gemǣlan',
 'edit'              => 'Ādihtan',
+'create'            => 'Scieppene',
 'editthispage'      => 'Ādihtan þisne tramet',
 'delete'            => 'āfeorsian',
 'deletethispage'    => 'Þisne tramet āfeorsian',
@@ -154,6 +156,7 @@ $messages = array(
 'mainpage-description' => 'Hēafodsīde',
 'portal'               => 'Gemǣnscipe Ingang',
 'portal-url'           => 'Project:Gemǣnscipe Ingang',
+'privacy'              => 'Ānlīepnesse þēaw',
 
 'versionrequired' => 'Fadunge $1 þæs MediaWicis nēodaþ',
 
@@ -175,6 +178,7 @@ $messages = array(
 'nstab-special'  => 'Syndrig',
 'nstab-image'    => 'Mētung',
 'nstab-template' => 'Bisen',
+'nstab-help'     => 'Helptramet',
 'nstab-category' => 'Flocc',
 
 # Main script and global functions
@@ -219,7 +223,7 @@ $messages = array(
 'loginsuccesstitle'          => 'Inmeldung gesǣlde',
 'loginsuccess'               => "'''Þu eart nū inmeldod tō {{SITENAME}} swā \"\$1\".'''",
 'nosuchuser'                 => 'Þǣr is nān brūcere be þǣm naman "$1".
-Edscēawa þīne wrītunge, oþþe brūc þone form under tō settene nīwne brūcendhordcleofan.',
+Edscēawa þīne wrītunge, oþþe brūc þone form under tō [[Special:UserLogin/signup|settene nīwne brūcendhordcleofan]].',
 'nosuchusershort'            => 'Þǣr is nān brūcend mid þǣm naman "<nowiki>$1</nowiki>".  Edscēawa on þīne wrītunge.',
 'acct_creation_throttle_hit' => 'Hwæt, þu hæfst gēo geseted $1 hordcleofan. Þu ne canst settan ǣnige māran.',
 'accountcreated'             => 'Hordcleofan gescapen',
@@ -237,13 +241,14 @@ Edscēawa þīne wrītunge, oþþe brūc þone form under tō settene nīwne br
 'headline_sample' => 'Hēafodlīnan traht',
 'image_sample'    => 'Bisen.jpg',
 'image_tip'       => 'Impod biliþ',
-'media_sample'    => 'Bisen.mp3',
+'media_sample'    => 'Bisen.ogg',
 'sig_tip'         => 'Þín namansegn mid tídstempunge',
 
 # Edit pages
 'summary'                => 'Scortnes',
 'minoredit'              => 'Þēos is lȳtlu ādihtung',
 'savearticle'            => 'Sparian tramet',
+'preview'                => 'Forescēawian',
 'showpreview'            => 'Forescēawian',
 'whitelistedittitle'     => 'Inmeldunge behófod tó ádihtenne',
 'whitelistedittext'      => 'Þu scealt $1 tó ádihtenne trametas.',
@@ -255,19 +260,19 @@ Edscēawa þīne wrītunge, oþþe brūc þone form under tō settene nīwne br
 'newarticletext'         => "Þu hæfst bende tō tramete gefolgod þe nū gīet ne stendeþ.
 Tō scieppene þone tramet, onginn þyddan in þǣre boxe under (sēo þone [[{{MediaWiki:Helppage}}|helptramet]] for mā gefrǣge).
 Gif þu hider misfōn cōme, cnoca þā þīnne webbscēaweres '''on bæc''' cnæpp.",
-'usercssjsyoucanpreview' => "<strong>Rǣd:</strong> Brūc þone 'Forescēawian' cnæpp tō āfandienne þīne nīwe css/js beforan sparunge.",
+'usercssjsyoucanpreview' => "'''Rǣd:''' Brūc þone 'Forescēawian' cnæpp tō āfandienne þīne nīwe css/js beforan sparunge.",
 'updated'                => '(Ednīwod)',
 'editingcomment'         => 'Ādihtung $1 (ymbsprǣc)',
 'yourtext'               => 'Þīn traht',
-'editingold'             => '<strong>WARNUNG: Þu ādihtest ealde fadunge þisses trametes.
-Gif þu hine sparie, ǣniga onwendunga gemacod siþþan þisse fadunge bēoþ sōðes forloren.</strong>',
+'editingold'             => "'''WARNUNG: Þu ādihtest ealde fadunge þisses trametes.
+Gif þu hine sparie, ǣniga onwendunga gemacod siþþan þisse fadunge bēoþ sōðes forloren.'''",
 'yourdiff'               => 'Tōdǣlednessa',
-'copyrightwarning2'      => 'Bidde macie nōt þæt ealla forðunga tō {{SITENAME}}
+'copyrightwarning2'      => "Bidde macie nōt þæt ealla forðunga tō {{SITENAME}}
 mæg bēon ādihted, gewended, oþþe āfyrðed fram ōðrum forðerum.
 Gif þu nelt þīne wrītunge tō bēonne ādihtod unmildheortlīce, þonne ne þafie hīe hēr.<br />
 Þu behǣtst ēac þæt þu selfa write þis, oþþe efenlǣhtest of sumre
 gemǣnscipes āgnunge oþþe gelīcum frēom horde (sēo $1 for āscungum).
-<strong>NE ÞAFIE EFENLǢHTSCIELDED WEORC BŪTAN GELĪEFNESSE!</strong>',
+'''NE ÞAFIE EFENLǢHTSCIELDED WEORC BŪTAN GELĪEFNESSE!'''",
 'longpagewarning'        => 'WARNUNG: Þes tramet is $1 kilobyta lang; sume
 webbscēaweras hæbben earfoðu mid þȳ þe hīe ādihtaþ trametas nēa oþþe lengran þonne 32kb.
 Bidde behycge þæt þu bricst þone tramet intō smalrum dǣlum.',
@@ -339,7 +344,7 @@ Bidde behycge þæt þu bricst þone tramet intō smalrum dǣlum.',
 # Recent changes
 'nchanges'        => '$1 hwierfunga',
 'recentchanges'   => 'Nīwlica hweorfunga',
-'rcnote'          => 'Under sind þā æftemestan <strong>$1</strong> hweorfunga in þǣm æftemestum <strong>$2</strong> dagum.',
+'rcnote'          => "Under {{PLURAL:$1|... '''1''' ...|sind þā æftemestan '''$1''' hweorfunga}} in {{PLURAL:$2|...|þǣm æftemestum '''$2''' dagum}}, . . $5, $4.",
 'rcnotefrom'      => 'Under sind þā hweorfunga siþþan <b>$2</b> (oþ <b>$1</b> geīewed).',
 'rclistfrom'      => 'Īewan nīwa hweorfunga, onginnenda of $1',
 'rcshowhideminor' => '$1 lȳtla ādihtunga',
@@ -489,7 +494,7 @@ Bidde behycge þæt þu bricst þone tramet intō smalrum dǣlum.',
 'rollback_short'     => 'Edhwierfan',
 'rollbacklink'       => 'Edhwierfan',
 'rollbackfailed'     => 'Edhwierft misfangen',
-'editcomment'        => 'Sēo ādihtungymbsprǣc wæs: "<i>$1</i>".', # only shown if there is an edit comment
+'editcomment'        => "Sēo ādihtungymbsprǣc wæs: \"''\$1''\".", # only shown if there is an edit comment
 'revertpage'         => 'Ācierde ādihtunga fram [[Special:Contributions/$2|$2]] ([[User talk:$2|Gesprec]]); wendede on bæc tō ǣrran fadunge fram [[User:$1|$1]]', # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
 'unprotectedarticle' => 'unweardod "[[$1]]"',
 'protect-title'      => 'Weardiende "$1"',
@@ -659,17 +664,22 @@ Bidde cēos ōðerne naman.',
 'imagelistall'     => 'eall',
 'watchlistall2'    => 'eall',
 'namespacesall'    => 'eall',
+'monthsall'        => 'eall',
 
 # E-mail address confirmation
 'confirmemail_body' => 'Hwilchwega, gewēne þu of IP stōwe $1, hæfþ in namanbēc gestt ǣnne hordcleofan
- "$2" mid þissum e-ǣrendes naman on {{SITENAME}}n.
+"$2" mid þissum e-ǣrendes naman on {{SITENAME}}n.
 
 Tō āsēðenne þæt þes hordcleofa tō þē gebyraþ and tō openienne
 e-ǣrenda hwilcnessa on {{SITENAME}}n, opena þisne bend in þīnum webbscēawere:
 
 $3
 
-Gif þis is *nā* þū, ne folga þisne bend. Þēos āsēðungrūn forealdaþ æt $4.',
+Gif þis is *nā* þū, ne folga þisne bend.
+
+$5
+
+Þēos āsēðungrūn forealdaþ æt $4.',
 
 # Scary transclusion
 'scarytranscludefailed'  => '[Bisenfeccung getrucod for $1; sarig]',
