@@ -10,108 +10,108 @@
 
 $messages = array(
 # User preference toggles
-'tog-underline'               => 'Bınê gıreyan de xete bance:',
-'tog-highlightbroken'         => 'Gıreyanê thalan/vengan {a href="" class="new"}wına{/a} (alternative: wına{a 
+'tog-underline'               => 'Bınê gırêyan de xete bıance:',
+'tog-highlightbroken'         => 'Gırêyanê vengan {a href="" class="new"}wına{/a} (alternative: wına{a 
 href="" class="internal"}?{/a}) bımocne.',
 'tog-justify'                 => 'Nuşte dı kıştan ser bıazne',
-'tog-hideminor'               => 'Vurnayışanê şenıkan perra „vurnayışê peyêni“ de bınımne/wedare',
-'tog-extendwatchlist'         => 'Lista seyr-kerdışia hirakerdiye',
-'tog-usenewrc'                => "Lista vurnayışanê peyênana hirakerdiye (''JavaScript'' lazımo)",
+'tog-hideminor'               => 'Vurnayışanê şenıkan pela „vurnayışê peyêni“ de bınımne',
+'tog-extendwatchlist'         => 'Lista seyr-kerdışia herakerdiye',
+'tog-usenewrc'                => "Lista vurnayışanê peyênana herakerdiye (''JavaScript'' lazımo)",
 'tog-numberheadings'          => 'Sernuşteyan be xo numre cışane',
-'tog-showtoolbar'             => 'Goceganê hacetanê vurnayışi bımocne (JavaScript)',
-'tog-editondblclick'          => 'Pê dı rey tıknayış perre sero bıguriye/bıxebetiye (JavaScript)',
-'tog-editsection'             => 'Vurnayışê tek tek qısman rê gıreyan bımocne',
-'tog-editsectiononrightclick' => 'Sernuştey qısıman sero be gocega raşte tıknaene bıvurne (JavaScript)',
-'tog-showtoc'                 => 'Tabloê tedeesteyan bımocne (de perranê be hirê sernuşteyan ra zêdêri/vêşêri de)',
+'tog-showtoolbar'             => 'Goceganê hacetanê vurnayışi bımocne (JavaScript lazımo)',
+'tog-editondblclick'          => 'Pê dı rey tıknayış pele sero bıxebetiye (JavaScript lazımo)',
+'tog-editsection'             => 'Gırêyanê [bıvurne] sera qısımê vurnayışi feal ke',
+'tog-editsectiononrightclick' => 'Sernuştey qısıman sero be gocega raşte tıknayene bıvurne (JavaScript lazımo)',
+'tog-showtoc'                 => 'Tabloyê tedeesteyan bımocne (de pelanê be hirê sernuşteyan ra vêşêri de)',
 'tog-rememberpassword'        => 'Parola mı bia xo viri',
-'tog-editwidth'               => 'Verınina perra cıdayışê nuştey tam bıaso',
-'tog-watchcreations'          => 'Perrê ke mı afernaê, lista mına seyr-kerdışi ke',
-'tog-watchdefault'            => 'Perrê ke mı vurnaê, lista mına seyr-kerdışi ke',
-'tog-watchmoves'              => 'Perrê ke mı kırışnaê, lista mına seyr-kerdışi ke',
-'tog-watchdeletion'           => 'Perrê ke mı esterıtê/kerdê paki, lista mına seyr-kerdışi ke',
-'tog-minordefault'            => 'Vurnayışanê xo pêroine ‘vurnayışo qıckek’ nışan bıde',
-'tog-previewontop'            => 'Verqayti perra nuştışi ser de bımocne',
+'tog-editwidth'               => 'Verıniya pela cıdayışê nuştey tam bıaso',
+'tog-watchcreations'          => 'Pelê ke mı afernayê, lista mına seyr-kerdışi ke',
+'tog-watchdefault'            => 'Pelê ke mı vurnayê, lista mına seyr-kerdışi ke',
+'tog-watchmoves'              => 'Pelê ke mı kırışnayê, lista mına seyr-kerdışi ke',
+'tog-watchdeletion'           => 'Pelê ke mı esterıtê, lista mına seyr-kerdışi ke',
+'tog-minordefault'            => 'Vurnayışanê xo pêrune ‘vurnayışo qıckek’ nışan bıde',
+'tog-previewontop'            => 'Verqayti pela nuştışi ser de bımocne',
 'tog-previewonfirst'          => 'Vurnayışo verên de verqayti tım bımocne',
-'tog-nocache'                 => 'Perran mia xo viri',
-'tog-enotifwatchlistpages'    => 'Perra ke ez seyr kenan, eke vurnê, mı rê e-mail bırışe',
-'tog-enotifusertalkpages'     => 'Pela mına werênayışi ke vurnê, mı rê e-mail bırışe',
+'tog-nocache'                 => 'Pelan mia xo viri',
+'tog-enotifwatchlistpages'    => 'Pela ke ez seyr kenan eke vurnayê mı rê e-mail bırışe',
+'tog-enotifusertalkpages'     => 'Pela mına werênayışi ke vurnayê, mı rê e-mail bırışe',
 'tog-enotifminoredits'        => 'Vurnayışanê qıckekan de ki mı rê e-mail bırışe',
 'tog-enotifrevealaddr'        => 'E-mailadresa mı emailanê xeberan de bımocne',
-'tog-shownumberswatching'     => 'Amarê (reqemê) karberanê seyrkerdoğan bımocne',
-'tog-fancysig'                => 'İmza xame (bê gıreo otomatik be perra karberan ser)',
-'tog-externaleditor'          => 'Editorê teberi standart bıgurene/bıxebetne',
-'tog-externaldiff'            => 'Têverşanayışan pê programê teberi vıraze',
-'tog-showjumplinks'           => 'Gırey "şo" aktif/feel ke',
-'tog-uselivepreview'          => 'Verqayto cınde bıgurene/bıxebetne (JavaScript) (hewna cerrebnayış dero)',
+'tog-shownumberswatching'     => 'Amarê karberanê seyrkerdoğan bımocne',
+'tog-fancysig'                => 'İmza xame (bê gırêo otomatik be pela karberan ser)',
+'tog-externaleditor'          => 'Editorê teberi standard bıxebetne (tenya seba ekspertano, komputerê şıma de ayarê xususiy lazımê)',
+'tog-externaldiff'            => 'Têverşanayışan pê programê teberi vıraze (tenya seba ekspertano, komputerê şıma de ayarê xususiy lazımê)',
+'tog-showjumplinks'           => 'Gırey "şo"y feal ke',
+'tog-uselivepreview'          => 'Verqayto cınde bıxebetne (JavaScript lazımo) (hewna cerrebnayış dero)',
 'tog-forceeditsummary'        => 'Mı ke xulasa kerde cı vira, hay be mı ser de',
-'tog-watchlisthideown'        => 'Vurnayışanê mı lista mına seyr-kerdışi de bınımne/wedare',
-'tog-watchlisthidebots'       => 'Vurnayışanê boti lista mına seyr-kerdışi de bınımne/wedare',
-'tog-watchlisthideminor'      => 'Vurnayışanê qıckekan lista mına seyr-kerdışi de bınımne/wedare',
+'tog-watchlisthideown'        => 'Vurnayışanê mı lista mına seyr-kerdışi de bınımne',
+'tog-watchlisthidebots'       => 'Vurnayışanê boti lista mına seyr-kerdışi de bınımne',
+'tog-watchlisthideminor'      => 'Vurnayışanê qıckekan lista mına seyr-kerdışi de bınımne',
 'tog-ccmeonemails'            => 'E-mailanê ke ez karberanê binan rê rışenan, mı rê kopya inan bırışe',
 'tog-diffonly'                => 'Qıyasê verziyonan de tek ferqan bımocne, perra butıne nê',
 'tog-showhiddencats'          => 'Kategoriyanê dızdine bımocne',
 
-'underline-always'  => 'tım',
-'underline-never'   => 'qet',
-'underline-default' => 'Qerar browseri (cıgeyraoği) dest dero',
+'underline-always'  => 'Tım',
+'underline-never'   => 'Qet',
+'underline-default' => 'Qerar cıgeyraoği dest dero',
 
 'skinpreview' => '(Verqayt)',
 
 # Dates
-'sunday'        => 'Bazar',
+'sunday'        => 'Kırê',
 'monday'        => 'Dışeme',
 'tuesday'       => 'Sêşeme',
 'wednesday'     => 'Çarşeme',
 'thursday'      => 'Phancşeme',
-'friday'        => 'Yene',
+'friday'        => 'Êne',
 'saturday'      => 'Şeme',
-'sun'           => 'Bzr',
-'mon'           => 'Dış',
-'tue'           => 'Sêş',
-'wed'           => 'Çar',
-'thu'           => 'Paş',
-'fri'           => 'Yen',
+'sun'           => 'Kır',
+'mon'           => 'Dşm',
+'tue'           => 'Sşm',
+'wed'           => 'Çrş',
+'thu'           => 'Pşm',
+'fri'           => 'Êne',
 'sat'           => 'Şem',
 'january'       => 'Çele',
-'february'      => 'Gucige',
-'march'         => 'Adare',
+'february'      => 'Şıbate',
+'march'         => 'Adar',
 'april'         => 'Nisane',
 'may_long'      => 'Gulane',
-'june'          => 'Hezirane',
-'july'          => 'Temmuze',
+'june'          => 'Heziran',
+'july'          => 'Temmuz',
 'august'        => 'Tebaxe',
 'september'     => 'Keşkelun',
-'october'       => 'Tişrino Verên',
-'november'      => 'Tişrino Peyên',
-'december'      => 'Gağande',
+'october'       => 'Tışrino Verên',
+'november'      => 'Tışrino Peyên',
+'december'      => 'Kanun',
 'january-gen'   => 'Çeley',
-'february-gen'  => 'Gucige',
-'march-gen'     => 'Adare',
+'february-gen'  => 'Şıbate',
+'march-gen'     => 'Adari',
 'april-gen'     => 'Nisane',
 'may-gen'       => 'Gulane',
-'june-gen'      => 'Hezirane',
-'july-gen'      => 'Temmuze',
+'june-gen'      => 'Hezirani',
+'july-gen'      => 'Temmuzi',
 'august-gen'    => 'Tebaxe',
 'september-gen' => 'Keşkeluni',
-'october-gen'   => 'Tişrinê Verêni',
-'november-gen'  => 'Tişrinê Peyêni',
-'december-gen'  => 'Gağande',
+'october-gen'   => 'Tışrinê Verêni',
+'november-gen'  => 'Tışrinê Peyêni',
+'december-gen'  => 'Kanuni',
 'jan'           => 'Çel',
-'feb'           => 'Guc',
+'feb'           => 'Şbt',
 'mar'           => 'Adr',
-'apr'           => 'Nis',
-'may'           => 'Gul',
-'jun'           => 'Hez',
-'jul'           => 'Tem',
-'aug'           => 'Teb',
+'apr'           => 'Nsn',
+'may'           => 'Gln',
+'jun'           => 'Hzr',
+'jul'           => 'Tmz',
+'aug'           => 'Tbx',
 'sep'           => 'Kşk',
 'oct'           => 'Tşv',
 'nov'           => 'Tşp',
-'dec'           => 'Gağ',
+'dec'           => 'Kan',
 
 # Categories related messages
-'pagecategories'           => '{{PLURAL:$1|Kategoriya|Kategoriyê}} perre',
-'category_header'          => 'Nuşteyê ke kategoriya "$1"(-i/-an) derê.',
+'pagecategories'           => '{{PLURAL:$1|Kategoriye|Kategoriy}}',
+'category_header'          => 'Pelê ke kategoriya "$1" derê',
 'subcategories'            => 'Kategoriyê bınêni',
 'category-media-header'    => 'Medyawa ke kategoriya "$1" (-i/-an) dera',
 'category-empty'           => "''Ena kategoriye de hewna qet nuştey ya ki medyay çıniyê.''",
@@ -125,10 +125,10 @@ href="" class="internal"}?{/a}) bımocne.',
 
 * [http://www.mediawiki.org/wiki/Manual:Configuration_settings Configuration settings list]
 * [http://www.mediawiki.org/wiki/Manual:FAQ MediaWiki FAQ]
-* [http://lists.wikimedia.org/mailman/listinfo/mediawiki-announce MediaWiki release mailing list]",
+* [https://lists.wikimedia.org/mailman/listinfo/mediawiki-announce MediaWiki release mailing list]",
 
-'about'          => 'Sero',
-'article'        => 'Perre',
+'about'          => 'Heqa',
+'article'        => 'Pela tedeesteyan',
 'newwindow'      => '(zerrey pençereyê de newey de beno a)',
 'cancel'         => 'Bıtexelne',
 'qbfind'         => 'Bıvêne',
@@ -165,15 +165,15 @@ href="" class="internal"}?{/a}) bımocne.',
 'create-this-page'  => 'Na pele bınuse',
 'delete'            => 'bıestere',
 'deletethispage'    => 'Ena pele bıestere',
-'undelete_short'    => 'Vurnayışê $1 peyser bia',
+'undelete_short'    => '{{PLURAL:$1|yew vurnayışi|$1 vurnayışan}} meestere',
 'protect'           => 'kılit ke',
-'protect_change'    => 'kılit-kerdene bıvurne',
+'protect_change'    => 'bıvurne',
 'protectthispage'   => 'Ena perre kılit ke',
 'unprotect'         => 'ake',
 'unprotectthispage' => 'Ena perre ake',
 'newpage'           => 'Perra newiye',
 'talkpage'          => 'Ena perre sero werêne',
-'talkpagelinktext'  => 'werênayış',
+'talkpagelinktext'  => 'Werênayış',
 'specialpage'       => 'Perra xase',
 'personaltools'     => 'Hacetê şexsi',
 'articlepage'       => 'nuşte',
@@ -189,63 +189,71 @@ href="" class="internal"}?{/a}) bımocne.',
 'categorypage'      => 'Perra kategoriye bıvêne',
 'viewtalkpage'      => 'Perra werênayışi bıvêne',
 'otherlanguages'    => 'zıwananê binan de',
+'redirectedfrom'    => '($1 ra neqıl bi)',
 'lastmodifiedat'    => 'Ena pele tewr peyên roca $2, $1 de biya rocaniye.', # $1 date, $2 time
 'viewcount'         => 'Ena perre {{PLURAL:$1|rae|$1 rey}} vêniya.',
 'protectedpage'     => 'Perra kılitkerdiye',
+'jumpto'            => 'Şo be:',
 'jumptonavigation'  => 'şiyayış',
 'jumptosearch'      => 'cıgeyre',
 
 # All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
 'aboutsite'            => 'Heqa {{SITENAME}} de',
-'aboutpage'            => 'Project:Sero',
+'aboutpage'            => 'Project:Heqa',
 'bugreports'           => 'Xebera xeteyan',
 'bugreportspage'       => 'Project:Xebera xeteyan',
 'copyright'            => 'Nuştey bınê Lisansê $1 de vêrenê.',
 'copyrightpagename'    => 'Heqa telifê {{SITENAME}}',
 'copyrightpage'        => '{{ns:project}}:Heqê telifi',
 'currentevents'        => 'Textey cerrebi',
-'currentevents-url'    => 'Project:Textey Cerrebi',
+'currentevents-url'    => 'Project:Textey cerrebi',
 'disclaimers'          => 'Reddê mesuliyeti',
 'disclaimerpage'       => 'Project:Reddê mesuliyetê bıngey',
-'edithelp'             => 'Çıturi vurniyeno?',
+'edithelp'             => 'Pheştdarina vurnayışi',
 'edithelppage'         => 'Help:Perre çıtewr vurniyena',
 'helppage'             => 'Help:Tedeestey',
 'mainpage'             => 'Pela Seri',
 'mainpage-description' => 'Pela Seri',
 'portal'               => 'Portalê cemaeti',
-'portal-url'           => 'Project:Portalê cemaeti',
+'portal-url'           => 'Project:Portalê Cemaeti',
 'privacy'              => 'Maddey dızdine',
 'privacypage'          => 'Project:Maddey dızdine',
 
 'badaccess' => 'Xeta mısadey',
 
 'ok'                      => 'Temam',
+'retrievedfrom'           => '"$1" ra ard',
 'youhavenewmessages'      => 'To rê estê $1 ($2).',
 'newmessageslink'         => 'mesajê newey',
-'newmessagesdifflink'     => 'vurnayışo peyên',
+'newmessagesdifflink'     => 'vurnayişo peyên',
 'youhavenewmessagesmulti' => 'To rê $1 de mesajê newey estê',
 'editsection'             => 'bıvurne',
+'editsection-brackets'    => '[$1]',
 'editold'                 => 'bıvurne',
+'viewsourceold'           => 'çımey bıvêne',
+'editsectionhint'         => 'Qısımê vurnayışi: $1',
 'toc'                     => 'Tedeestey',
 'showtoc'                 => 'bımocne',
 'hidetoc'                 => 'bınımne',
 'thisisdeleted'           => 'Bıvêne ya ki restore ke $1?',
 'viewdeleted'             => '$1 bıvêne?',
 'restorelink'             => '{{PLURAL:$1|yew vurnayışo esterıte (pakbiyae)|$1 vurnayışê esterıtey (pakbiyaey)}}',
-'feedlinks'               => 'Weyikerdış (feed):',
-'feed-invalid'            => 'Invalid subscription feed type (Beğşo nêvêrde).',
-'red-link-title'          => '$1 (heta nıka nênusiyao)',
+'feedlinks'               => 'Weyikerdış:',
+'feed-invalid'            => 'Tipê weyikerdışê beğşê nêvêrdey.',
+'site-rss-feed'           => 'Weyi-kerdışê $1 RSSi',
+'site-atom-feed'          => 'Weyi-kerdışê $1 Atomi',
+'red-link-title'          => '$1 (pele çina)',
 
 # Short words for each namespace, by default used in the namespace tab in monobook
 'nstab-main'      => 'nuşte',
 'nstab-user'      => 'Pela Karberi',
 'nstab-media'     => 'Pela Medya',
-'nstab-special'   => 'xas',
+'nstab-special'   => 'Pela xase',
 'nstab-project'   => 'Pela Procey',
 'nstab-image'     => 'Dosya',
 'nstab-mediawiki' => 'Mesaj',
 'nstab-template'  => 'Şablon',
-'nstab-help'      => 'Pela Pheşti',
+'nstab-help'      => 'Pela pheşti',
 'nstab-category'  => 'Kategoriye',
 
 # Main script and global functions
@@ -272,6 +280,7 @@ Seba /qandê lista pelanê xasanê vêrdeyan kerem ke: [[Special:SpecialPages|{{
 'yourpasswordagain'         => 'Parola reyna bınusne',
 'remembermypassword'        => 'Na/In komputer de mı biya xo viri',
 'login'                     => 'Cıkewe',
+'nav-login-createaccount'   => 'Cıkewe / hesab vıraze',
 'loginprompt'               => "Seba ke mumkın bo şıma bıkewê pela {{SITENAME}}, programê internetê şıma de ''cookies''i gereke aktifi bê.",
 'userlogin'                 => 'Cıkewe ya ki hesab vıraze',
 'logout'                    => 'Veciye',
@@ -294,7 +303,8 @@ If you choose to provide it, this will be used for giving you attribution for yo
 'wrongpassword'             => 'Parola ğeleta. Rêna / fına bıcerrebne .',
 'passwordtooshort'          => 'Parola to nêvêrena ya ki zaf kılma.
 It must have at least $1 characters and be different from your username.',
-'mailmypassword'            => 'Mı rê e-mail sera parola bırışe',
+'mailmypassword'            => 'E-mail sera parola newiye bırışe',
+'accountcreated'            => 'Hesab vıraciya',
 'loginlanguagelabel'        => 'Zıwan: $1',
 
 # Edit pages
@@ -306,12 +316,27 @@ It must have at least $1 characters and be different from your username.',
 'newarticle'   => '(Newe)',
 
 # History pages
-'cur'  => 'ferq',
-'last' => 'pey',
+'revisionasof'     => 'Verziyonê roca $1ine',
+'previousrevision' => '← Rewşa kıhanêre',
+'cur'              => 'ferq',
+'last'             => 'pey',
 
 # Revision deletion
 'rev-delundel' => 'bımocne/bınımne',
 
+# Diffs
+'lineno'   => 'Rêza $1i:',
+'editundo' => 'peyser biya',
+
+# Search results
+'search-result-size' => '$1 ({{PLURAL:$2|1 çekuye|$2 çekuy}})',
+'powersearch'        => 'Cıgeyrayışo hera',
+'powersearch-legend' => 'Cıgeyrayışo hera',
+'powersearch-ns'     => 'Cayanê nameyan de cıgeyrayış:',
+'powersearch-redir'  => 'Raçarnayeyan lista ke',
+'powersearch-field'  => 'Cıgeyre',
+'search-external'    => 'Cıgeyrayışê teberi',
+
 # Preferences page
 'mypreferences'   => 'tercihê mı',
 'qbsettings-none' => 'çino',
@@ -319,7 +344,7 @@ It must have at least $1 characters and be different from your username.',
 'prefs-rc'        => 'Vurnayışê peyêni',
 'prefs-watchlist' => 'Lista seyr-kerdışi',
 'saveprefs'       => 'Qeyd ke',
-'oldpassword'     => 'Parola khane:',
+'oldpassword'     => 'Parola kıhane:',
 'newpassword'     => 'Parola newiye:',
 'retypenew'       => 'Parola newiye tekrar ke:',
 'timezonelegend'  => 'Warey saete',
@@ -329,11 +354,15 @@ It must have at least $1 characters and be different from your username.',
 'rightsnone' => '(çino)',
 
 # Recent changes
-'recentchanges' => 'Vurnayışê peyêni',
-'diff'          => 'ferq',
-'hist'          => 'ver',
-'hide'          => 'Bınımne',
-'show'          => 'Bımocne',
+'recentchanges'   => 'Vurnayışê peyêni',
+'diff'            => 'ferq',
+'hist'            => 'ver',
+'hide'            => 'Bınımne',
+'show'            => 'Bımocne',
+'minoreditletter' => 'q',
+'newpageletter'   => 'N',
+'boteditletter'   => 'b',
+'sectionlink'     => '→',
 
 # Recent changes linked
 'recentchangeslinked' => 'Ney sero vurnayışi',
@@ -352,14 +381,16 @@ It must have at least $1 characters and be different from your username.',
 'imagelist_user' => 'Karber',
 
 # Image description page
+'filehist'          => 'Tarixê dosya',
 'filehist-datetime' => 'Tarix/Zeman',
 'filehist-user'     => 'Karber',
+'imagelinks'        => 'Gıreyê dosya',
 'noimage-linktext'  => 'Bar ke',
 
 # File deletion
 'filedelete'        => '$1 bıestere',
 'filedelete-legend' => 'Dosya bıestere',
-'filedelete-submit' => 'bıestere',
+'filedelete-submit' => 'Bıestere',
 
 # MIME search
 'download' => 'bar ke',
@@ -370,16 +401,17 @@ It must have at least $1 characters and be different from your username.',
 'brokenredirects-edit'   => '(bıvurne)',
 'brokenredirects-delete' => '(bıestere)',
 
-'withoutinterwiki-submit' => 'bımocne',
+'withoutinterwiki-submit' => 'Bımocne',
 
 # Miscellaneous special pages
+'nbytes'            => '$1 {{PLURAL:$1|bayt|bayti}}',
 'ncategories'       => '$1 {{PLURAL:$1|Kategoriye|Kategoriy}}',
 'shortpages'        => 'Pelê kılmi',
 'longpages'         => 'Pelê dergi',
 'listusers'         => 'Lista karberan',
 'newpages'          => 'Pelê newey',
 'newpages-username' => 'Namey Karberi:',
-'ancientpages'      => 'Pelê khanêri',
+'ancientpages'      => 'Pelê kıhanêri',
 'move'              => 'bere',
 
 # Book sources
@@ -390,6 +422,9 @@ It must have at least $1 characters and be different from your username.',
 'log-search-submit'   => 'Şo',
 
 # Special:AllPages
+'alphaindexline' => '$1 ra $2ine',
+'nextpage'       => 'Pela peyêne ($1)',
+'prevpage'       => 'Pela verêne ($1)',
 'allpagessubmit' => 'Şo',
 
 # Special:Categories
@@ -400,25 +435,73 @@ It must have at least $1 characters and be different from your username.',
 
 # Watchlist
 'watchlist'   => 'lista mına seyr-kerdışi',
-'mywatchlist' => 'lista mına seyr-kerdışi',
+'mywatchlist' => 'Lista mına seyr-kerdışi',
 'watch'       => 'bıgê seyr-kerdış',
+'unwatch'     => 'Endi seyr meke',
+
+# Displayed when you click the "watch" button and it is in the process of watching
+'watching'   => 'Seyr ke...',
+'unwatching' => 'Seyr meke...',
 
 # Delete/protect/revert
-'deletepage'   => 'Pele bıestere',
-'rollbacklink' => 'peyser biya',
+'deletepage'            => 'Pele bıestere',
+'deletereasonotherlist' => 'Sebebo bin',
+'rollbacklink'          => 'peyser bia',
 
 # Restrictions (nouns)
 'restriction-edit' => 'Bıvurne',
 
+# Namespace form on various pages
+'blanknamespace' => '(Ser)',
+
 # Contributions
 'mycontris' => 'iştırakê mı',
 
+'sp-contributions-newbies'  => 'Tenya iştıraqanê karberanê neweyan bımocne',
+'sp-contributions-username' => 'Adresa IPy ya ki namey karberi:',
+
 # What links here
-'whatlinkshere' => 'Gırey be pele',
+'whatlinkshere'       => 'Gırey be pele',
+'whatlinkshere-page'  => 'Pele:',
+'whatlinkshere-links' => '← gırey',
+
+# Block/unblock
+'blocklink'    => 'kılit ke',
+'unblocklink'  => 'ake',
+'contribslink' => 'iştıraki',
+'autoblocker'  => 'Şıma otomatikmen kılit biy, çıke adresa şımawa \'\'IP\'\'y terefê "[[User:$1|$1]]" gureniyena. 
+Sebebê kılit-biyayışê $1\'i: "$2"o',
+'blocklogpage' => 'Protokolê kıliti',
+
+# Move page
+'1movedto2'  => '[[$1]] berd be [[$2]]',
+'movereason' => 'Sebeb:',
+
+# Thumbnails
+'thumbnail-more' => 'Gırd ke',
 
 # Tooltip help for the actions
-'tooltip-pt-userpage' => 'Pela mına karberi',
-'tooltip-pt-mytalk'   => 'Pela mına werênayışi',
+'tooltip-pt-userpage'      => 'Pela şımawa karberi',
+'tooltip-pt-mytalk'        => 'Pela şımawa werênayışi',
+'tooltip-pt-login'         => 'Seba cıkotışi şıma rê dewato, labelê no zeruri niyo.',
+'tooltip-pt-logout'        => 'Veciye',
+'tooltip-ca-talk'          => 'Pela tedeesteyan sero werênayış',
+'tooltip-ca-edit'          => 'Tı eşkenay na pele bıvurnê.
+Kerem ke, qeyd-kerdış ra ver gozega verqayti bıxebıtne.',
+'tooltip-search'           => 'Zerrey {{SITENAME}} de cıgeyre',
+'tooltip-search-go'        => 'Ebe nê namey şo yew pele, eke esta',
+'tooltip-search-fulltext'  => 'Seba nê meqaley pelan saye ke',
+'tooltip-n-mainpage'       => 'Pela Seri bıvêne',
+'tooltip-n-portal'         => 'Heqa projey de, tı çı eşkenay bıkerê, koti çiy vêniyenê',
+'tooltip-n-currentevents'  => 'Vurnayışanê peyênan de melumatê pey bıvêne',
+'tooltip-n-recentchanges'  => 'Wiki de lista vurnayışanê peyênan.',
+'tooltip-n-randompage'     => 'Kamci pele ke raşt amey bar ke',
+'tooltip-n-help'           => 'Cayê doş-kerdışi.',
+'tooltip-t-whatlinkshere'  => 'Lista pelanê wikiya pêroina ke tiya gırê bena',
+'tooltip-t-upload'         => 'Dosya bar ke',
+'tooltip-t-specialpages'   => 'Lista pelanê xasanê pêroinan bımocne',
+'tooltip-ca-nstab-main'    => 'Pela tedeesteyan bıvêne',
+'tooltip-ca-nstab-special' => 'Na yew pelê da xususiya, şıma nêşenê nae bıvurnê',
 
 # Attribution
 'lastmodifiedatby' => 'Ena pele tewr peyên roca $2, $1 by $3. de biya rocaniye', # $1 date, $2 time, $3 user
@@ -426,6 +509,13 @@ It must have at least $1 characters and be different from your username.',
 # Special:NewImages
 'ilsubmit' => 'Cıgeyre',
 
+# Bad image list
+'bad_image_list' => 'Şeklo umumi wınayo:
+
+Tenya çiyo ke beno lista (rezê ke be * dest kenê cı) çıman ver de vêniyeno.
+Yew rêze de gırêyo sıfteyın gani gırêyo de dosya xırabıne bo.
+Na rêze de her gırêyo bin zey istisna vêniyeno, yanê pelê ke dosya beno ke sero rêzbiyaye asena.',
+
 'exif-gaincontrol-0' => 'çino',
 
 # AJAX search
