@@ -108,10 +108,12 @@ $messages = array(
 'otherlanguages'   => 'Na nkótá isúsu',
 'redirectedfrom'   => '(Eyendísí útá $1)',
 'redirectpagesub'  => 'Lokásá la boyendisi',
+'jumpto'           => 'Kokɛndɛ na:',
 'jumptosearch'     => 'boluki',
 
 # All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
 'aboutsite'            => 'elɔ́kɔ elobí {{SITENAME}}',
+'copyrightpage'        => '{{ns:project}}:Mikokisi',
 'currentevents'        => 'Elɔ́kɔ ya sika',
 'edithelp'             => 'Kobimisela bosálisi',
 'mainpage'             => 'Lokásá ya libosó',
@@ -127,6 +129,9 @@ $messages = array(
 'toc'                => 'Etápe',
 'showtoc'            => 'komɔ́nisa',
 'hidetoc'            => 'kobomba',
+'site-rss-feed'      => 'Ebale RSS ya $1',
+'site-atom-feed'     => 'Ebale Atom ya $1',
+'page-rss-feed'      => 'Ebale RSS ya « $1 »',
 
 # Short words for each namespace, by default used in the namespace tab in monobook
 'nstab-main'     => 'ekakoli',
@@ -136,17 +141,19 @@ $messages = array(
 'nstab-category' => 'loléngé',
 
 # General errors
-'error' => 'Mbéba',
+'error'         => 'Mbéba',
+'viewsourcefor' => 'na $1',
 
 # Login and logout pages
 'yourname'                => 'Nkómbó ya ekitoli :',
+'yourpassword'            => 'Banda nayó:',
 'yourpasswordagain'       => 'Banda naíno :',
 'login'                   => 'komíkitola (log in)',
 'nav-login-createaccount' => 'Komíkomisa tǒ kokɔtɔ',
 'userlogin'               => 'Komíkomisa tǒ kokɔtɔ',
 'logout'                  => 'kolongwa',
 'userlogout'              => 'kolongwa (log out)',
-'nologin'                 => 'Omíkomísí naíno tɛ̂ ? $1.',
+'nologin'                 => 'Omíkomísí naíno tɛ̂? $1.',
 'nologinlink'             => 'Míkomísá yɔ̌-mɛ́i',
 'gotaccount'              => 'Omíkomísí naíno ? $1.',
 'createaccountmail'       => 'na mokánda',
@@ -161,6 +168,7 @@ $messages = array(
 'bold_tip'        => 'Nkomá ya mbinga',
 'italic_sample'   => 'Nkomá ya kotɛ́ngama',
 'italic_tip'      => 'Nkomá ya kotɛ́ngama',
+'extlink_sample'  => 'http://www.example.com Litɛ́mɛ ya ekangisi',
 'headline_sample' => 'Nkomá ya litɛ́mɛ',
 'headline_tip'    => 'Litɛ́mɛ ya emeko 2',
 
@@ -171,6 +179,7 @@ $messages = array(
 'watchthis'              => 'Kolanda lokásá loye',
 'savearticle'            => 'kobómbisa ekakoli',
 'preview'                => 'Botáli',
+'newarticle'             => '(Sika)',
 'editing'                => 'Kobimisela « $1 »',
 'editingcomment'         => 'Kokoma « $1 » (ndimbola)',
 'yourtext'               => 'Nkomá na yɔ̌',
@@ -223,6 +232,7 @@ $messages = array(
 'recentchanges'   => 'Mbóngwana ya nsúka',
 'rcnote'          => "Áwa o nsé {{PLURAL:$1|ezalí mbóngwana '''1'''|izalí mbóngwana '''$1'''}} o {{PLURAL:$2|mokɔlɔ|mikɔlɔ '''$2'''}} ya nsúka, {{PLURAL:$1|etángámí|itángámí}} o $3.",
 'rcshowhideminor' => '$1 mbóngwana ya mokɛ́',
+'rcshowhidebots'  => '$1 barobot',
 'rcshowhidemine'  => '$1 mbóngwana ya ngáí',
 'rclinks'         => 'Komɔ́nisa mbóngwana $1 ya nsúka o mikɔ́lɔ $2<br />$3',
 'diff'            => 'mbó.',
@@ -244,6 +254,9 @@ $messages = array(
 # Special:ImageList
 'imagelist_date' => 'Mokɔlɔ',
 
+# Image description page
+'filehist' => 'Mokóló ya kásá',
+
 # File deletion
 'filedelete-submit' => 'Kolímwisa',
 
@@ -262,6 +275,7 @@ $messages = array(
 'doubleredirects' => 'Boyendisi mbala míbalé',
 
 # Miscellaneous special pages
+'nbytes'                  => '$1 {{PLURAL:$1|okté|baokté}}',
 'nmembers'                => '{{PLURAL:$1|ekakoli|bikakoli}} $1',
 'uncategorizedpages'      => 'Nkásá izángí loléngé',
 'uncategorizedcategories' => 'Ndéngé izángí loléngé',
@@ -277,6 +291,9 @@ $messages = array(
 # Book sources
 'booksources-go' => 'Kɛndɛ́',
 
+# Special:Log
+'log' => 'Bapasɔ́',
+
 # Special:AllPages
 'allpages'       => 'Nkásá ínsɔ',
 'alphaindexline' => '$1 kina $2',
@@ -305,7 +322,7 @@ $messages = array(
 'watch'                => 'Kolanda',
 'watchthispage'        => 'Kolanda lokásá loye',
 'unwatch'              => 'Kolanda tɛ́',
-'watchlist-details'    => '{{PLURAL:$1|lokásá $1 lolandámí|nkásá $1 ilandámí}}, longola nkásá ya ntembe.',
+'watchlist-details'    => '{{PLURAL:$1|Lokásá $1 lolandámí|Nkásá $1 ilandámí}}, longola nkásá ya ntembe.',
 'wlnote'               => "Áwa o nsé {{PLURAL:$1|ezalí mbóngwana ya nsúka|izalí mbóngwana '''$1''' ya nsúka}} o {{PLURAL:$2|ngonga|ngonga '''$2'''}} ya nsúka.",
 'wlshowlast'           => 'Komɔ́nisa ngónga $1 ya nsúka, mikɔ́lɔ $2 mya nsúka tǒ $3',
 'watchlist-show-bots'  => 'Komɔ́nisa mbóngwana ya bot',
@@ -348,6 +365,7 @@ $messages = array(
 'move-watch'              => 'Kolánda lokásá loye',
 'movepagebtn'             => 'Kobóngola lokásá',
 'movedto'                 => 'nkómbó ya sika',
+'revertmove'              => 'kozóngela',
 'delete_and_move'         => 'Kolímwisa mpé kobóngola nkómbó',
 'delete_and_move_confirm' => 'Boye, kolímwisa lokásá',
 'delete_and_move_reason'  => 'Ntína ya bolímwisi mpé bobóngoli bwa nkómbó',
@@ -368,9 +386,11 @@ $messages = array(
 'tooltip-pt-preferences'    => 'Malúli ma ngáí',
 'tooltip-pt-watchlist'      => 'Nkásá nalandí mpɔ̂ na mbóngwana',
 'tooltip-pt-mycontris'      => 'Nkásá nakomí',
+'tooltip-pt-logout'         => 'Ombémbóí',
 'tooltip-search'            => 'Boluki {{SITENAME}}',
 'tooltip-p-logo'            => 'Lokásá ya libosó',
 'tooltip-n-mainpage'        => 'Kokɛndɛ na Lokásá ya libosó',
+'tooltip-n-help'            => 'Lisálisi',
 'tooltip-ca-nstab-template' => 'Komɔ́nisela emekoli',
 'tooltip-ca-nstab-category' => 'Komɔ́nisela lokásá ya loléngé',
 
