@@ -1,15 +1,14 @@
 <?php
 /** Neapolitan (Nnapulitano)
  *
- * @addtogroup Language
+ * @ingroup Language
+ * @file
  *
  * @author Carmine Colacino
+ * @author Cryptex
  * @author E. abu Filumena
  * @author SabineCretella
- * @author Cryptex
- * @author SPQRobin
- * @author G - ג
- * @author Nike
+ * @author לערי ריינהארט
  */
 
 $fallback = 'it';
@@ -35,40 +34,58 @@ $messages = array(
 'underline-never'  => 'Màje',
 
 # Dates
-'sunday'    => 'dumméneca',
-'monday'    => 'lunnerì',
-'tuesday'   => 'marterì',
-'wednesday' => 'miercurì',
-'thursday'  => 'gioverì',
-'friday'    => 'viernarì',
-'saturday'  => 'sàbbato',
-'january'   => 'jennaro',
-'february'  => 'frevàro',
-'march'     => 'màrzo',
-'april'     => 'abbrile',
-'may_long'  => 'màjo',
-'june'      => 'giùgno',
-'july'      => 'luglio',
-'august'    => 'aústo',
-'september' => 'settembre',
-'october'   => 'ottobbre',
-'november'  => 'nuvembre',
-'december'  => 'dicèmbre',
-'jan'       => 'jen',
-'feb'       => 'fre',
-'mar'       => 'mar',
-'apr'       => 'abb',
-'may'       => 'maj',
-'jun'       => 'giu',
-'jul'       => 'lug',
-'aug'       => 'aus',
-'sep'       => 'set',
-'oct'       => 'ott',
-'nov'       => 'nuv',
-'dec'       => 'dic',
+'sunday'        => 'dumméneca',
+'monday'        => 'lunnerì',
+'tuesday'       => 'marterì',
+'wednesday'     => 'miercurì',
+'thursday'      => 'gioverì',
+'friday'        => 'viernarì',
+'saturday'      => 'sàbbato',
+'sun'           => 'dum',
+'mon'           => 'lun',
+'tue'           => 'mar',
+'wed'           => 'mier',
+'thu'           => 'gio',
+'fri'           => 'ven',
+'sat'           => 'sab',
+'january'       => 'jennaro',
+'february'      => 'frevàro',
+'march'         => 'màrzo',
+'april'         => 'abbrile',
+'may_long'      => 'màjo',
+'june'          => 'giùgno',
+'july'          => 'luglio',
+'august'        => 'aústo',
+'september'     => 'settembre',
+'october'       => 'ottobbre',
+'november'      => 'nuvembre',
+'december'      => 'dicèmbre',
+'january-gen'   => 'jennaro',
+'february-gen'  => 'frevaro',
+'march-gen'     => 'màrzo',
+'april-gen'     => 'abbrile',
+'may-gen'       => 'maggio',
+'june-gen'      => 'giùgno',
+'july-gen'      => 'luglio',
+'august-gen'    => 'aùsto',
+'september-gen' => 'settembre',
+'october-gen'   => 'ottovre',
+'november-gen'  => 'nuvembre',
+'december-gen'  => 'dicembre',
+'jan'           => 'jen',
+'feb'           => 'fre',
+'mar'           => 'mar',
+'apr'           => 'abb',
+'may'           => 'maj',
+'jun'           => 'giu',
+'jul'           => 'lug',
+'aug'           => 'aus',
+'sep'           => 'set',
+'oct'           => 'ott',
+'nov'           => 'nuv',
+'dec'           => 'dic',
 
-# Bits of text used by many pages
-'categories'      => '{{PLURAL:$1|Categurìa|Categurìe}}',
+# Categories related messages
 'category_header' => 'Paggene rìnt\'a categurìa "$1"',
 'subcategories'   => 'Categurìe secunnarie',
 
@@ -86,6 +103,11 @@ $messages = array(
 'mytalk'         => "'E mmie chiacchieriàte",
 'anontalk'       => 'Chiacchierate pe chisto IP',
 
+# Metadata in edit box
+'metadata_help' => 'Metadate:',
+
+'errorpagetitle'    => 'Sbaglio',
+'returnto'          => 'Torna a $1.',
 'help'              => 'Ajùto',
 'search'            => 'Truova',
 'searchbutton'      => 'Truova',
@@ -113,23 +135,22 @@ $messages = array(
 'otherlanguages'    => 'Ate léngue',
 'redirectedfrom'    => "(Redirect 'a $1)",
 'lastmodifiedat'    => "Urdema cagnamiénto pe' a paggena: $2, $1.", # $1 date, $2 time
-'viewcount'         => 'Chesta paggena è stata lètta {{plural:$1|una vòta|$1 vòte}}.',
+'viewcount'         => 'Chesta paggena è stata lètta {{PLURAL:$1|una vòta|$1 vòte}}.',
 'jumpto'            => 'Vaje a:',
 'jumptonavigation'  => 'navigazione',
 'jumptosearch'      => 'truova',
 
 # All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
-'aboutsite'       => "'Nfrummazione ncòpp'a {{SITENAME}}",
-'aboutpage'       => "Project:'Nfrummazione",
-'disclaimers'     => 'Avvertimiènte',
-'disclaimerpage'  => 'Project:Avvertimiènte generale',
-'edithelp'        => 'Guida',
-'helppage'        => 'Help:Ajùto',
-'mainpage'        => 'Paggena prencepale',
-'portal'          => "Porta d''a cummunetà",
-'portal-url'      => "Project:Porta d''a cummunetà",
-'sitesupport'     => 'Donazzione',
-'sitesupport-url' => 'Project:Donazzione',
+'aboutsite'            => "'Nfrummazione ncòpp'a {{SITENAME}}",
+'aboutpage'            => "Project:'Nfrummazione",
+'disclaimers'          => 'Avvertimiènte',
+'disclaimerpage'       => 'Project:Avvertimiènte generale',
+'edithelp'             => 'Guida',
+'helppage'             => 'Help:Ajùto',
+'mainpage'             => 'Paggena prencepale',
+'mainpage-description' => 'Paggena prencepale',
+'portal'               => "Porta d''a cummunetà",
+'portal-url'           => "Project:Porta d''a cummunetà",
 
 'badaccess' => "Nun haje 'e premmesse abbastante.",
 
@@ -158,7 +179,7 @@ $messages = array(
 'badtitle'        => "'O nnomme nun è jùsto",
 
 # Login and logout pages
-'logouttext'                 => "<strong>Site asciùte.</strong><br />
+'logouttext'                 => "'''Site asciùte.'''<br />
 Putite cuntinuà a ausà {{SITENAME}} comme n'utente senza nomme, o si nò putite trasì n'ata vota, cu 'o stesso nomme o cu n'ato nomme.",
 'welcomecreation'            => "== Bemmenuto, $1! ==
 
@@ -203,7 +224,7 @@ Putite cuntinuà a ausà {{SITENAME}} comme n'utente senza nomme, o si nò putit
 'loginreqpagetext'  => "Pe' veré ate ppaggene abbesognate $1.",
 'accmailtitle'      => "'O password è stato mannato.",
 'accmailtext'       => '\'A password pe ll\'utente "$1" fuje mannata ô nnerizzo $2.',
-'previewnote'       => "Chesta è sola n'anteprimma; 'e cagnamiénte â paggena NUN songo ancora sarvate!",
+'previewnote'       => "'''Chesta è sola n'anteprimma; 'e cagnamiénte â paggena NUN songo ancora sarvate!'''",
 'editing'           => "Cagnamiento 'e $1",
 'templatesused'     => "Template ausate 'a chesta paggena:",
 
@@ -258,14 +279,13 @@ Putite cuntinuà a ausà {{SITENAME}} comme n'utente senza nomme, o si nò putit
 'fileexists-thumb' => "<center>'''Immagine esistente'''</center>",
 'uploadedimage'    => 'ha carecato "[[$1]]"',
 
-# Image list
-'ilsubmit'         => 'Truova',
-'byname'           => 'nomme',
-'imgdelete'        => 'scanc',
+# Special:ImageList
+'imagelist_name' => 'Nomme',
+
+# Image description page
 'filehist-user'    => 'Utente',
 'imagelinks'       => 'Jonte ê ffiure',
 'noimage-linktext' => 'carrecarlo mmo',
-'imagelist_name'   => 'Nomme',
 
 # Random page
 'randompage'         => 'Na paggena qualsiase',
@@ -281,20 +301,21 @@ Putite cuntinuà a ausà {{SITENAME}} comme n'utente senza nomme, o si nò putit
 'nlinks'       => '$1 {{PLURAL:$1|cullegamiento|cullegamiente}}',
 'popularpages' => "Paggene cchiù 'speziunate",
 'wantedpages'  => 'Paggene cchiù addemannate',
-'allpages'     => "Tutte 'e ppaggene",
 'shortpages'   => 'Paggene curte',
 'longpages'    => 'Paggene cchiú longhe',
-'specialpages' => 'Paggene speciale',
 'newpages'     => 'Paggene cchiù frische',
 'move'         => 'Spusta',
 'movethispage' => 'Spusta chesta paggena',
 
-'categoriespagetext' => "Lista cumpleta d\"e categurie presente ncopp' 'o sito.",
-
-# Special:Allpages
+# Special:AllPages
+'allpages'       => "Tutte 'e ppaggene",
 'allarticles'    => "Tutt' 'e vvoce",
 'allinnamespace' => "Tutt' 'e ppaggene d&#39;&#39;o namespace $1",
 
+# Special:Categories
+'categories'         => 'Categurìe',
+'categoriespagetext' => "Lista cumpleta d\"e categurie presente ncopp' 'o sito.",
+
 # Watchlist
 'addedwatch'   => 'Aggiunto ai Osservate Speciale tue',
 'watch'        => 'Secuta',
@@ -342,7 +363,7 @@ Putite cuntinuà a ausà {{SITENAME}} comme n'utente senza nomme, o si nò putit
 'blocklink'          => 'ferma',
 'blocklogpage'       => 'Blocche',
 'blocklogentry'      => 'ha fermato "[[$1]]" pe\' nu mumento \'e $2 $3',
-'blocklogtext'       => "Chesta è 'a lista d&#39;&#39;e azzione 'e blocco e sblocco utente.  'E nnerizze IP bloccate automaticamente nun nce so'. Addumannà 'a [[Special:Ipblocklist|lista IP bloccate]] pp' 'a lista d&#39;&#39;e nnerizze e nomme utente 'o ca blocco nce sta.",
+'blocklogtext'       => "Chesta è 'a lista d&#39;&#39;e azzione 'e blocco e sblocco utente.  'E nnerizze IP bloccate automaticamente nun nce so'. Addumannà 'a [[Special:IPBlockList|lista IP bloccate]] pp' 'a lista d&#39;&#39;e nnerizze e nomme utente 'o ca blocco nce sta.",
 
 # Move page
 'movearticle'             => "Spusta 'a paggena",
@@ -374,6 +395,7 @@ Putite cuntinuà a ausà {{SITENAME}} comme n'utente senza nomme, o si nò putit
 'import-logentry-upload' => 'ha mpurtato [[$1]] trammeto upload',
 
 # Tooltip help for the actions
+'tooltip-pt-logout' => 'Jésce (logout)',
 'tooltip-minoredit' => 'Rénne chìsto cagnamiénto cchiù ppiccirìllo.',
 'tooltip-save'      => "Sàrva 'e cagnamiénte.",
 'tooltip-preview'   => "Primma 'e sarvà, vìre primma chille ca hê cagnàte!",
@@ -381,16 +403,13 @@ Putite cuntinuà a ausà {{SITENAME}} comme n'utente senza nomme, o si nò putit
 # Attribution
 'others' => 'ate',
 
-# Spam protection
-'subcategorycount'     => "Ce {{PLURAL:$1|sta n'ata categurìa|stanno ate $1 categurìe}} rìnt'a chésta categurìa.",
-'categoryarticlecount' => 'Nce {{PLURAL:$1|sta na voce|stanno $1 voce}} intâ sta categoria.',
-
 # Info page
 'numedits'    => "Nummero 'e cagnamiente (articulo): $1",
 'numwatchers' => "Nummero 'e asservature: $1",
 
-# Special:Newimages
+# Special:NewImages
 'noimages' => "Nun nc'è nind' 'a veré.",
+'ilsubmit' => 'Truova',
 
 'exif-xyresolution-i' => '$1 punte pe pollice (dpi)',
 
@@ -406,7 +425,7 @@ Putite cuntinuà a ausà {{SITENAME}} comme n'utente senza nomme, o si nò putit
 'exif-subjectdistancerange-0' => 'Scanusciuta',
 
 # External editor support
-'edit-externally-help' => "Pe piglià cchiù nfromma veré 'e [http://meta.wikimedia.org/wiki/Help:External_editors struzione] ('n ngrese)",
+'edit-externally-help' => "Pe piglià cchiù nfromma veré 'e [http://www.mediawiki.org/wiki/Manual:External_editors struzione] ('n ngrese)",
 
 # 'all' in various places, this might be different for inflected languages
 'namespacesall' => 'Tutte',
@@ -428,4 +447,7 @@ Putite cuntinuà a ausà {{SITENAME}} comme n'utente senza nomme, o si nò putit
 'autoredircomment' => 'Redirect â paggena [[$1]]',
 'autosumm-new'     => 'Paggena nuova: $1',
 
+# Special:SpecialPages
+'specialpages' => 'Paggene speciale',
+
 );
