@@ -82,6 +82,7 @@ $messages = array(
 'deletethispage'   => 'Ekarta disi pagine',
 'protect'          => 'Protekte',
 'protectthispage'  => 'Protekte disi pagine',
+'newpage'          => 'Novi pagine',
 'talkpage'         => 'Diskuse disi pagine',
 'talkpagelinktext' => 'Diskusione',
 'specialpage'      => 'Spesial Pagine',
@@ -123,7 +124,7 @@ $messages = array(
 # Short words for each namespace, by default used in the namespace tab in monobook
 'nstab-main'      => 'Artikle',
 'nstab-user'      => 'Useren pagine',
-'nstab-special'   => 'Spesial',
+'nstab-special'   => 'Spesial pagine',
 'nstab-project'   => 'Projetal pagine',
 'nstab-mediawiki' => 'Mesaje',
 'nstab-template'  => 'Shablone',
@@ -137,9 +138,9 @@ $messages = array(
 
 # Login and logout pages
 'logouttitle'                => 'Useren eksignato',
-'logouttext'                 => '<strong>Vu es nun eksignatat.</strong><br />
+'logouttext'                 => "'''Vu es nun eksignatat.'''<br />
 Vu pove kontinua usa {{SITENAME}} anonimim, o vu pove riensignata
-kom li sami o altri usere.',
+kom li sami o altri usere.",
 'loginpagetitle'             => 'Useren ensignato',
 'yourname'                   => 'Usere-nome:',
 'yourpassword'               => 'Pasa-vorde:',
@@ -193,6 +194,7 @@ Forsan lu ha bli ekarta fro li wiki, o rinomat.
 Proba [[Special:Search|sercho sur li wiki]] por relatet pagines.',
 
 # Diffs
+'lineno'                  => 'Linie $1:',
 'compareselectedversions' => 'Kompara selektet versiones',
 
 # Search results
@@ -203,6 +205,7 @@ Proba [[Special:Search|sercho sur li wiki]] por relatet pagines.',
 'prevn'                 => 'lasti $1',
 'nextn'                 => 'sekuenti $1',
 'viewprevnext'          => 'Vida ($1) ($2) ($3).',
+'search-result-size'    => '$1 ({{PLURAL:$2|1 vorde|$2 vordes}})',
 'showingresults'        => "Montrant subu {{PLURAL:$1|'''1''' resulte|'''$1''' resultes}} amaxim komensant fro #'''$2'''.",
 'showingresultsnum'     => "Montrant subu {{PLURAL:$3|'''1''' result|'''$3''' results}} komensant fro #'''$2'''.",
 'powersearch'           => 'Sercha',
@@ -216,6 +219,7 @@ Proba [[Special:Search|sercho sur li wiki]] por relatet pagines.',
 'searchresultshead' => 'Sercha',
 
 # Recent changes
+'nchanges'        => '$1 {{PLURAL:$1|chanjo|chanjos}}',
 'recentchanges'   => 'Resenti chanjos',
 'rcnote'          => "Subu es {{PLURAL:$1| '''1''' chanje|li lasti '''$1''' chanjes}} in li lasti {{PLURAL:$2|die|'''$2''' dies}}, fro $3.",
 'rcshowhideminor' => '$1 minori modifikos',
@@ -225,6 +229,8 @@ Proba [[Special:Search|sercho sur li wiki]] por relatet pagines.',
 'hist'            => 'hist',
 'hide'            => 'Kasha',
 'show'            => 'Montra',
+'minoreditletter' => 'm',
+'newpageletter'   => 'N',
 
 # Recent changes linked
 'recentchangeslinked' => 'Afini chanjos',
@@ -341,10 +347,12 @@ Si vu voli plu tardim ekarta li pagine fro vun observa-liste, klikta \"Desobserv
 'sp-contributions-submit'  => 'Sercha',
 
 # What links here
-'whatlinkshere'      => 'Tum kel kupla hir',
-'whatlinkshere-page' => 'Pagine:',
+'whatlinkshere'       => 'Tum kel kupla hir',
+'whatlinkshere-page'  => 'Pagine:',
+'whatlinkshere-links' => '← linkes',
 
 # Block/unblock
+'ipbreason'    => 'Resone:',
 'badipaddress' => 'Non-valid IP adrese',
 'contribslink' => 'Kontributiones',
 
@@ -354,6 +362,7 @@ Si vu voli plu tardim ekarta li pagine fro vun observa-liste, klikta \"Desobserv
 'movedto'                 => 'movat a',
 '1movedto2'               => '[[$1]] movat a [[$2]]',
 '1movedto2_redir'         => '[[$1]] movat a [[$2]] via ri-adreso',
+'movereason'              => 'Resone:',
 'delete_and_move'         => 'Ekarta e mova',
 'delete_and_move_confirm' => 'Yes, ekarta li pagine',
 'delete_and_move_reason'  => 'Ekartat por fa spatie por movo',
@@ -367,7 +376,7 @@ Si vu voli plu tardim ekarta li pagine fro vun observa-liste, klikta \"Desobserv
 'allmessagesmodified' => 'Montra nur modifikates',
 
 # Tooltip help for the actions
-'tooltip-pt-mytalk'      => 'Men parla-pagine',
+'tooltip-pt-mytalk'      => 'Vun parla-pagine',
 'tooltip-pt-preferences' => 'Men preferos',
 'tooltip-pt-logout'      => 'Eksignata',
 'tooltip-p-logo'         => 'Chefi pagine',
